kimai  | ++ cat /opt/kimai/version.txt
kimai  | 2.57.0
kimai  | + KIMAI=2.57.0
kimai  | + echo 2.57.0
kimai  | + waitForDB
kimai  | ++ awk -F '[/:@]' '{print $4}'
kimai-db  | 2026-09-23 21:47:44+02:00 [Note] [Entrypoint]: Entrypoint script for MariaDB Server 1:11.8.9+maria~ubu2404 started.
kimai-db  | 2026-09-23 21:47:45+02:00 [Warn] [Entrypoint]: /sys/fs/cgroup///memory.pressure not writable, functionality unavailable to MariaDB
kimai-db  | 2026-09-23 21:47:45+02:00 [Note] [Entrypoint]: Switching to dedicated user 'mysql'
kimai-db  | 2026-09-23 21:47:45+02:00 [Note] [Entrypoint]: Entrypoint script for MariaDB Server 1:11.8.9+maria~ubu2404 started.
kimai-db  | 2026-09-23 21:47:45+02:00 [Note] [Entrypoint]: Starting temporary server
kimai-db  | 2026-09-23 21:47:45+02:00 [Note] [Entrypoint]: Waiting for server startup
kimai-db  | 2026-09-23 21:47:45 0 [Note] Starting MariaDB 11.8.9-MariaDB-ubu2404 source revision bf9193a939f515e95dd8def1a5468088c91cede6 server_uid XJIP6QbJ4lHnWnCFysMCKMDH7hM= as process 56
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: Compressed tables use zlib 1.3
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: Number of transaction pools: 1
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: Using crc32 + pclmulqdq instructions
kimai     | + DATABASE_USER=kimai
kimai     | ++ awk -F '[/:@]' '{print $5}'
kimai     | + DATABASE_PASS=QmPdc2mLG4tTiD84IHFSprsT
kimai     | ++ awk -F '[/:@]' '{print $6}'
kimai     | + DATABASE_HOST=kimai-db
kimai     | ++ awk -F '[/:@]' '{print $7}'
kimai     | + DATABASE_PORT=3306
kimai     | ++ awk -F '[/?]' '{print $4}'
kimai     | + DATABASE_BASE=kimai
kimai     | + re='^[0-9]+$'
kimai     | + [[ 3306 =~ ^[0-9]+$ ]]
kimai     | Wait for database connection ...
kimai     | + echo 'Wait for database connection ...'
kimai     | + php /dbtest.php kimai-db kimai 3306 kimai QmPdc2mLG4tTiD84IHFSprsT
kimai     | Testing DB:Connection established
kimai     | + echo 'Connection established'
kimai     | + handleStartup
kimai     | + '[' -z 512M ']'
kimai     | + sed -i 's/memory_limit.*/memory_limit=512M/g' /usr/local/etc/php/php.ini
kimai     | + cp /assets/monolog.yaml /opt/kimai/config/packages/monolog.yaml
kimai     | + '[' -z '' ']'
kimai     | ++ id -u www-data
kimai     | + USER_ID=33
kimai     | + '[' -z '' ']'
kimai     | ++ id -g www-data
kimai     | + GROUP_ID=33
kimai     | + grep -w 33 /etc/group
kimai     | Group already exists
kimai     | + echo Group already exists
kimai     | + id 33
kimai     | User already exists
kimai     | + echo User already exists
kimai     | + '[' -e /use_apache ']'
kimai     | ++ id -nu 33
kimai     | + export APACHE_RUN_USER=www-data
kimai     | + APACHE_RUN_USER=www-data
kimai     | ++ id -ng 33
kimai     | + export APACHE_RUN_GROUP=www-data
kimai     | + APACHE_RUN_GROUP=www-data
kimai-db  | 2026-09-23 21:47:45 0 [Warning] mariadbd: io_uring_queue_init() failed with EPERM: sysctl kernel.io_uring_disabled has the value 2, or 1 and the user of the process is not a member of sysctl kernel.io_uring_group. (see man 2 io_uring_setup).
kimai-db  | create_uring failed: falling back to libaio
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: Using Linux native AIO
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: innodb_buffer_pool_size_max=8388608m, innodb_buffer_pool_size=128m
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: Completed initialization of buffer pool
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: File system buffers for log disabled (block size=512 bytes)
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: End of log at LSN=1841510
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: Opened 3 undo tablespaces
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: 128 rollback segments in 3 undo tablespaces are active.
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: Setting file './ibtmp1' size to 12.000MiB. Physically writing the file full; Please wait ...
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: File './ibtmp1' size is now 12.000MiB.
kimai-db  | 2026-09-23 21:47:45 0 [Note] InnoDB: log sequence number 1841510; transaction id 1781
kimai-db  | 2026-09-23 21:47:45 0 [Note] Plugin 'FEEDBACK' is disabled.
kimai-db  | 2026-09-23 21:47:45 0 [Note] Plugin 'wsrep-provider' is disabled.
kimai-db  | 2026-09-23 21:47:47 0 [Note] mariadbd: ready for connections.
kimai-db  | Version: '11.8.9-MariaDB-ubu2404'  socket: '/run/mysqld/mysqld.sock'  port: 0  mariadb.org binary distribution
kimai-db  | 2026-09-23 21:47:48+02:00 [Note] [Entrypoint]: Temporary server started.
kimai-db  | 2026-09-23 21:47:48+02:00 [Note] [Entrypoint]: Backing up system database to system_mysql_backup_11.6.2-MariaDB.sql.zst
kimai-db  | 2026-09-23 21:47:49+02:00 [Note] [Entrypoint]: Backing up complete
kimai-db  | 2026-09-23 21:47:49+02:00 [Note] [Entrypoint]: Starting mariadb-upgrade
kimai-db  | The --upgrade-system-tables option was used, user tables won't be touched.
kimai-db  | Major version upgrade detected from 11.6.2-MariaDB to 11.8.9-MariaDB. Check required!
kimai-db  | Phase 1/8: Checking and upgrading mysql database
kimai-db  | Processing databases
kimai-db  | mysql
kimai-db  | mysql.column_stats                                 OK
kimai-db  | mysql.columns_priv                                 OK
kimai-db  | mysql.db                                           OK
kimai-db  | mysql.event                                        OK
kimai-db  | mysql.func                                         OK
kimai-db  | mysql.global_priv                                  OK
kimai-db  | mysql.gtid_slave_pos                               OK
kimai-db  | mysql.help_category                                OK
kimai-db  | mysql.help_keyword                                 OK
kimai-db  | mysql.help_relation                                OK
kimai-db  | mysql.help_topic                                   OK
kimai-db  | mysql.index_stats                                  OK
kimai-db  | mysql.innodb_index_stats                           OK
kimai-db  | mysql.innodb_table_stats                           OK
kimai-db  | mysql.plugin                                       OK
kimai-db  | mysql.proc                                         OK
kimai-db  | mysql.procs_priv                                   OK
kimai-db  | mysql.proxies_priv                                 OK
kimai-db  | mysql.roles_mapping                                OK
kimai-db  | mysql.servers                                      OK
kimai-db  | mysql.table_stats                                  OK
kimai-db  | mysql.tables_priv                                  OK
kimai-db  | mysql.time_zone                                    OK
kimai-db  | mysql.time_zone_leap_second                        OK
kimai-db  | mysql.time_zone_name                               OK
kimai-db  | mysql.time_zone_transition                         OK
kimai-db  | mysql.time_zone_transition_type                    OK
kimai-db  | mysql.transaction_registry                         OK
kimai-db  | Phase 2/8: Installing used storage engines... Skipped
kimai-db  | Phase 3/8: Running 'mysql_fix_privilege_tables'
kimai-db  | Phase 4/8: Fixing views... Skipped
kimai-db  | Phase 5/8: Fixing table and database names ... Skipped
kimai-db  | Phase 6/8: Checking and upgrading tables... Skipped
kimai-db  | Phase 7/8: uninstalling plugins
kimai-db  | Phase 8/8: Running 'FLUSH PRIVILEGES'
kimai-db  | OK
kimai-db  | 2026-09-23 21:47:56+02:00 [Note] [Entrypoint]: Finished mariadb-upgrade
kimai-db  | 2026-09-23 21:47:56+02:00 [Note] [Entrypoint]: Stopping temporary server
kimai-db  | 2026-09-23 21:47:56 0 [Note] mariadbd (initiated by: unknown): Normal shutdown
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: FTS optimize thread exiting.
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Starting shutdown...
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Removed temporary tablespace data file: "./ibtmp1"
kimai-db  | 2026-09-23 21:47:56 0 [Note] Shutdown completed; log sequence number 1841510; transaction id 1785
kimai-db  | 2026-09-23 21:47:56 0 [Note] mariadbd: Shutdown complete
kimai-db  | 2026-09-23 21:47:56+02:00 [Note] [Entrypoint]: Temporary server stopped
kimai-db  | 2026-09-23 21:47:56 0 [Note] Starting MariaDB 11.8.9-MariaDB-ubu2404 source revision bf9193a939f515e95dd8def1a5468088c91cede6 server_uid XJIP6QbJ4lHnWnCFysMCKMDH7hM= as process 1
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Compressed tables use zlib 1.3
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Number of transaction pools: 1
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Using crc32 + pclmulqdq instructions
kimai-db  | 2026-09-23 21:47:56 0 [Warning] mariadbd: io_uring_queue_init() failed with EPERM: sysctl kernel.io_uring_disabled has the value 2, or 1 and the user of the process is not a member of sysctl kernel.io_uring_group. (see man 2 io_uring_setup).
kimai-db  | create_uring failed: falling back to libaio
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Using Linux native AIO
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: innodb_buffer_pool_size_max=8388608m, innodb_buffer_pool_size=128m
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Completed initialization of buffer pool
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: File system buffers for log disabled (block size=512 bytes)
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: End of log at LSN=1841510
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Opened 3 undo tablespaces
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: 128 rollback segments in 3 undo tablespaces are active.
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Setting file './ibtmp1' size to 12.000MiB. Physically writing the file full; Please wait ...
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: File './ibtmp1' size is now 12.000MiB.
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: log sequence number 1841510; transaction id 1781
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Loading buffer pool(s) from /var/lib/mysql/ib_buffer_pool
kimai-db  | 2026-09-23 21:47:56 0 [Note] Plugin 'FEEDBACK' is disabled.
kimai-db  | 2026-09-23 21:47:56 0 [Note] Plugin 'wsrep-provider' is disabled.
kimai-db  | 2026-09-23 21:47:56 0 [Note] InnoDB: Buffer pool(s) load completed at 260923 21:47:56
kimai-db  | 2026-09-23 21:47:58 0 [Note] Server socket created on IP: '0.0.0.0', port: '3306'.
kimai-db  | 2026-09-23 21:47:58 0 [Note] Server socket created on IP: '::', port: '3306'.
kimai-db  | 2026-09-23 21:47:58 0 [Note] mariadbd: Event Scheduler: Loaded 0 events
kimai-db  | 2026-09-23 21:47:58 0 [Note] mariadbd: ready for connections.
kimai-db  | Version: '11.8.9-MariaDB-ubu2404'  socket: '/run/mysqld/mysqld.sock'  port: 3306  mariadb.org binary distribution
kimai     | + export APACHE_PID_FILE=/var/run/apache2/apache2.pid
kimai     | + APACHE_PID_FILE=/var/run/apache2/apache2.pid
kimai     | + export APACHE_RUN_DIR=/var/run/apache2
kimai     | + APACHE_RUN_DIR=/var/run/apache2
kimai     | + export APACHE_LOCK_DIR=/var/lock/apache2
kimai     | + APACHE_LOCK_DIR=/var/lock/apache2
kimai     | + export APACHE_LOG_DIR=/var/log/apache2
kimai     | + APACHE_LOG_DIR=/var/log/apache2
kimai     | + export LANG=C
kimai     | + LANG=C
kimai     | + prepareKimai
kimai     | + /opt/kimai/bin/console -n kimai:install
kimai     |  Start installation ...
kimai     | Database `kimai` for connection named default already exists. Skipped.
kimai     |  Creating database ...
kimai     | [notice] Migrating up to DoctrineMigrations\Version20251214160001
kimai     | [notice] finished in 11759.4ms, used 56M memory, 74 migrations executed, 262 sql queries
kimai     | 
kimai     |  [OK] Successfully migrated to version: DoctrineMigrations\Version20251214160001
kimai     | 
kimai     | 
kimai     |  Rebuilding cache ...
kimai     | 
kimai     |  // Clearing the cache for the prod environment with debug false                
kimai     | 
kimai     |  [OK] Cache for the "prod" environment (debug=false) was successfully cleared.  
kimai     | 
kimai     | 
kimai     |  // Warming up the cache for the prod environment with debug false              
kimai     | 
kimai     |  [OK] Cache for the "prod" environment (debug=false) was successfully warmed.   
kimai     | 
kimai     | 
kimai     |  [OK] Successfully installed Kimai version 2.57.0 🎉                            
kimai     | 
kimai     | + '[' '!' -z Drill-4c03a46f733ef5d0e0dcd72c ']'
kimai     | + '[' '!' -a admin@example.com ']'
kimai     | + /opt/kimai/bin/console kimai:user:create admin admin@example.com ROLE_SUPER_ADMIN Drill-4c03a46f733ef5d0e0dcd72c
kimai     | 
kimai     |  [OK] Success! Created user: admin                                              
kimai     | 
kimai     | + echo 2.57.0
kimai     | + echo 'Kimai is ready'
kimai     | + runServer
kimai     | + /opt/kimai/bin/console kimai:reload --env=prod
kimai     | Kimai is ready
kimai     |  Validating config file syntax ...
kimai     | 
kimai     |  [OK] All 26 YAML files contain valid syntax.                                   
kimai     | 
kimai     | 
kimai     | 
kimai     |  [OK] All 602 XLIFF files contain valid syntax.                                 
kimai     | 
kimai     | 
kimai     |  Rebuilding your cache, please be patient ...
kimai     | 
kimai     |  // Clearing the cache for the prod environment with debug false                
kimai     | 
kimai     | [2026-09-23T19:46:26.424647+00:00] deprecation.INFO: User Deprecated: Enabling the controller resolver automapping feature has been deprecated. Symfony Mapped Route Parameters should be used as replacement. (DoctrineExtension.php:934 called by DoctrineExtension.php:543, https://github.com/doctrine/DoctrineBundle/pull/1804, package doctrine/doctrine-bundle) {"exception":"[object] (ErrorException(code: 0): User Deprecated: Enabling the controller resolver automapping feature has been deprecated. Symfony Mapped Route Parameters should be used as replacement. (DoctrineExtension.php:934 called by DoctrineExtension.php:543, https://github.com/doctrine/DoctrineBundle/pull/1804, package doctrine/doctrine-bundle) at /opt/kimai/vendor/doctrine/deprecations/src/Deprecation.php:208)"} {"channel":"deprecation"}
kimai     |  [OK] Cache for the "prod" environment (debug=false) was successfully cleared.  
kimai     | 
kimai     | 
kimai     |  // Warming up the cache for the prod environment with debug false              
kimai     | 
kimai     |  [OK] Cache for the "prod" environment (debug=false) was successfully warmed.   
kimai     | 
kimai     | 
kimai     |  [OK] Kimai config was reloaded                                                 
kimai     | 
kimai     | + chown -R 33:33 /opt/kimai/var
kimai     | + '[' -e /use_apache ']'
kimai     | + exec /usr/sbin/apache2 -D FOREGROUND
kimai     | [Wed Sep 23 21:46:40.604360 2026] [mpm_prefork:notice] [pid 1:tid 1] AH00163: Apache/2.4.67 (Debian) configured -- resuming normal operations
kimai     | [Wed Sep 23 21:46:40.604410 2026] [core:notice] [pid 1:tid 1] AH00094: Command line: '/usr/sbin/apache2 -D FOREGROUND'
kimai     | localhost:8001 127.0.0.1 - - [23/Sep/2026:21:46:56 +0200] "GET / HTTP/1.1" 302 626 "-" "curl/7.88.1"
kimai     | localhost:8001 172.18.0.3 - - [23/Sep/2026:21:47:16 +0200] "GET / HTTP/1.1" 302 626 "-" "Go-http-client/1.1"
kimai     | localhost:8001 127.0.0.1 - - [23/Sep/2026:21:47:26 +0200] "GET / HTTP/1.1" 302 626 "-" "curl/7.88.1"
kimai     | [Wed Sep 23 21:47:39.626312 2026] [mpm_prefork:notice] [pid 1:tid 1] AH00170: caught SIGWINCH, shutting down gracefully
kimai     | ++ cat /opt/kimai/version.txt
kimai     | 2.57.0
kimai     | + KIMAI=2.57.0
kimai     | + echo 2.57.0
kimai     | + waitForDB
kimai     | ++ awk -F '[/:@]' '{print $4}'
kimai     | + DATABASE_USER=kimai
kimai     | ++ awk -F '[/:@]' '{print $5}'
kimai     | + DATABASE_PASS=QmPdc2mLG4tTiD84IHFSprsT
kimai     | ++ awk -F '[/:@]' '{print $6}'
kimai     | + DATABASE_HOST=kimai-db
kimai     | ++ awk -F '[/:@]' '{print $7}'
kimai     | + DATABASE_PORT=3306
kimai     | ++ awk -F '[/?]' '{print $4}'
kimai     | + DATABASE_BASE=kimai
kimai     | + re='^[0-9]+$'
kimai     | + [[ 3306 =~ ^[0-9]+$ ]]
kimai     | + echo 'Wait for database connection ...'
kimai     | + php /dbtest.php kimai-db kimai 3306 kimai QmPdc2mLG4tTiD84IHFSprsT
kimai     | Wait for database connection ...
kimai     | + echo 'Connection established'
kimai     | + handleStartup
kimai     | + '[' -z 512M ']'
kimai     | + sed -i 's/memory_limit.*/memory_limit=512M/g' /usr/local/etc/php/php.ini
kimai     | Testing DB:Connection established
kimai     | + cp /assets/monolog.yaml /opt/kimai/config/packages/monolog.yaml
kimai     | + '[' -z '' ']'
kimai     | ++ id -u www-data
kimai     | + USER_ID=33
kimai     | + '[' -z '' ']'
kimai     | ++ id -g www-data
kimai     | + GROUP_ID=33
kimai     | + grep -w 33 /etc/group
kimai     | + echo Group already exists
kimai     | + id 33
kimai     | Group already exists
kimai     | + echo User already exists
kimai     | + '[' -e /use_apache ']'
kimai     | User already exists
kimai     | ++ id -nu 33
kimai     | + export APACHE_RUN_USER=www-data
kimai     | + APACHE_RUN_USER=www-data
kimai     | ++ id -ng 33
kimai     | + export APACHE_RUN_GROUP=www-data
kimai     | + APACHE_RUN_GROUP=www-data
kimai     | + export APACHE_PID_FILE=/var/run/apache2/apache2.pid
kimai     | + APACHE_PID_FILE=/var/run/apache2/apache2.pid
kimai     | + export APACHE_RUN_DIR=/var/run/apache2
kimai     | + APACHE_RUN_DIR=/var/run/apache2
kimai     | + export APACHE_LOCK_DIR=/var/lock/apache2
kimai     | + APACHE_LOCK_DIR=/var/lock/apache2
kimai     | + export APACHE_LOG_DIR=/var/log/apache2
kimai     | + APACHE_LOG_DIR=/var/log/apache2
kimai     | + export LANG=C
kimai     | + LANG=C
kimai     | + prepareKimai
kimai     | + /opt/kimai/bin/console -n kimai:install
kimai     |  Start installation ...
kimai     | Database `kimai` for connection named default already exists. Skipped.
kimai     |  Creating database ...
kimai     | 
kimai     |  [OK] Already at the latest version ("DoctrineMigrations\Version20251214160001")
kimai     | 
kimai     |  Rebuilding cache ...
kimai     | 
kimai     |  // Clearing the cache for the prod environment with debug false                
kimai     | 
kimai     | [2026-09-23T19:48:01.497427+00:00] deprecation.INFO: User Deprecated: Enabling the controller resolver automapping feature has been deprecated. Symfony Mapped Route Parameters should be used as replacement. (DoctrineExtension.php:934 called by DoctrineExtension.php:543, https://github.com/doctrine/DoctrineBundle/pull/1804, package doctrine/doctrine-bundle) {"exception":"[object] (ErrorException(code: 0): User Deprecated: Enabling the controller resolver automapping feature has been deprecated. Symfony Mapped Route Parameters should be used as replacement. (DoctrineExtension.php:934 called by DoctrineExtension.php:543, https://github.com/doctrine/DoctrineBundle/pull/1804, package doctrine/doctrine-bundle) at /opt/kimai/vendor/doctrine/deprecations/src/Deprecation.php:208)"} {"channel":"deprecation"}
kimai     |  [OK] Cache for the "prod" environment (debug=false) was successfully cleared.  
kimai     | 
kimai     | 
kimai     |  // Warming up the cache for the prod environment with debug false              
kimai     | 
kimai     |  [OK] Cache for the "prod" environment (debug=false) was successfully warmed.   
kimai     | 
kimai     | 
kimai     |  [OK] Successfully installed Kimai version 2.57.0 🎉                            
kimai     | 
kimai     | + '[' '!' -z Drill-4c03a46f733ef5d0e0dcd72c ']'
kimai     | + '[' '!' -a admin@example.com ']'
kimai     | + /opt/kimai/bin/console kimai:user:create admin admin@example.com ROLE_SUPER_ADMIN Drill-4c03a46f733ef5d0e0dcd72c
kimai     | 
kimai     |  [ERROR] email: This e-mail address is already in use.                          
kimai     | 
kimai     |  [ERROR] username: The username is already used.                                
kimai     | 
kimai     | + echo 2.57.0
kimai     | + echo 'Kimai is ready'
kimai     | Kimai is ready
kimai     | + runServer
kimai     | + /opt/kimai/bin/console kimai:reload --env=prod
kimai     |  Validating config file syntax ...
kimai     | 
kimai     |  [OK] All 26 YAML files contain valid syntax.                                   
kimai     | 
kimai     | 
kimai     | 
kimai     |  [OK] All 602 XLIFF files contain valid syntax.                                 
kimai     | 
kimai     | 
kimai     |  Rebuilding your cache, please be patient ...
kimai     | 
kimai     |  // Clearing the cache for the prod environment with debug false                
kimai     | 
kimai     | [2026-09-23T19:48:16.092031+00:00] deprecation.INFO: User Deprecated: Enabling the controller resolver automapping feature has been deprecated. Symfony Mapped Route Parameters should be used as replacement. (DoctrineExtension.php:934 called by DoctrineExtension.php:543, https://github.com/doctrine/DoctrineBundle/pull/1804, package doctrine/doctrine-bundle) {"exception":"[object] (ErrorException(code: 0): User Deprecated: Enabling the controller resolver automapping feature has been deprecated. Symfony Mapped Route Parameters should be used as replacement. (DoctrineExtension.php:934 called by DoctrineExtension.php:543, https://github.com/doctrine/DoctrineBundle/pull/1804, package doctrine/doctrine-bundle) at /opt/kimai/vendor/doctrine/deprecations/src/Deprecation.php:208)"} {"channel":"deprecation"}
kimai     |  [OK] Cache for the "prod" environment (debug=false) was successfully cleared.  
kimai     | 
kimai     | 
kimai     |  // Warming up the cache for the prod environment with debug false              
kimai     | 
kimai     |  [OK] Cache for the "prod" environment (debug=false) was successfully warmed.   
kimai     | 
kimai     | 
kimai     |  [OK] Kimai config was reloaded                                                 
kimai     | 
kimai     | + chown -R 33:33 /opt/kimai/var
kimai     | + '[' -e /use_apache ']'
kimai     | + exec /usr/sbin/apache2 -D FOREGROUND
kimai     | [Wed Sep 23 21:48:27.943076 2026] [mpm_prefork:notice] [pid 1:tid 1] AH00163: Apache/2.4.67 (Debian) configured -- resuming normal operations
kimai     | [Wed Sep 23 21:48:27.943383 2026] [core:notice] [pid 1:tid 1] AH00094: Command line: '/usr/sbin/apache2 -D FOREGROUND'
kimai     | localhost:8001 127.0.0.1 - - [23/Sep/2026:21:48:30 +0200] "GET / HTTP/1.1" 302 626 "-" "curl/7.88.1"
kimai     | localhost:8001 172.18.0.3 - - [23/Sep/2026:21:48:36 +0200] "GET / HTTP/1.1" 302 626 "-" "Go-http-client/1.1"
